Sphinx extension for the IDL Language
=====================================

This is a sphinx extension for IDL. It provides a domain (``sphinx_idl.domain``) which provides directives to describe IDL procedures and functions, as well as an autodoc extension (``sphinx_idl.auto``) which provides a way to generate RST-based documentation from IDL source files.

You can read the documentation and installation instructions at http://sphinx-idl.readthedocs.io/en/latest/index.html.
